@@ -156,7 +156,7 @@ SESSION_KEYS = [
     "ds_pk",
     "project_pk",
     "page_num",
-    "page_id",  
+    "page_id",
     "col_pk",
     "datasource",
     "project",
@@ -692,9 +692,16 @@ def get_pageprocess_section_html(request):
         edited_other = []
 
         for key, values in items_edited:
+            test = False
+            for v in values:
+                if v[0]:
+                    test = True
+            if not test:
+                continue
+
             if key in settings.APIS_ENTITIES.keys():
                 new_values = []
-                for v in values:
+                for v in values:           
                     new_values.append(get_json_entity(v[0]))
                     if not "version" in v[1].keys():
                         v[1]["version"] = "original"
@@ -708,6 +715,8 @@ def get_pageprocess_section_html(request):
 
                 new_values = []
                 for v in values:
+                    if not v[0]:
+                        continue
                     log.info(f"v0 is {v[0]}, key is {key}, v0type is {type(v[0])}")
                     new_values.append(get_json_rel(rel_class=key, rel_id=v[0].id))
                     if not "version" in v[1].keys():
@@ -736,20 +745,27 @@ def get_pageprocess_section_html(request):
         created_other = []
 
         for key, values in items_created:
-
+            test = False
+            for v in values:
+                if v:
+                    test = True
+            if not test:
+                continue
             if key in settings.APIS_ENTITIES.keys():
-                new_values = [get_json_entity(v) for v in values]
+                new_values = [get_json_entity(v) for v in values if v]
                 table = get_generic_entity_progress_table(data=new_values, version=False)
                 created_entities.append((key, table))
 
             elif key in list(filter(lambda x: re.match(r"[A-Z]", x), settings.APIS_RELATIONS.keys())):
-                new_values = [get_json_rel(instance=v) for v in values]
+                log.info(f"key is: {key}")
+                new_values = [get_json_rel(instance=v) for v in values if v]
                 table = get_generic_relation_progress_table(data=new_values, version=False)
                 created_relations.append((key, table))
 
             else:
                 created_other.append((key, values))
 
+
         context_created["created_entities"] = created_entities
         context_created["created_relations"] = created_relations
         context_created["created_other"] = created_other
@@ -832,7 +848,7 @@ class EditorAllSectionsView(View):
                     #  implement it correctly. For entities with a lot of relations, this causes delaus in loading them.
                         # fixme: __maintainence__ __gpirgie__ implement pagination via ajax
 
-                    tb_object)  
+                    tb_object)
             side_bar.append((title_card, tb_object, ''.join([x.title() for x in match]), tb_object_open))
         form = get_custom_generic_entities_form(entity.title())
         form = form(instance=instance)
